@@ -1,9 +1,9 @@
 huff <-
 function (huffdataset, origins, locations, attrac, dist,    
-                         gamma = 1, lambda = -2, atype= "pow", dtype = "pow", 
-                         gamma2 = NULL, lambda2 = NULL, output = "shares",
+                         gamma = 1, lambda = -2, atype = "pow", dtype = "pow", 
+                         gamma2 = NULL, lambda2 = NULL,
                          localmarket_dataset = NULL, origin_id = NULL, localmarket = NULL, 
-                         check_df = TRUE)
+                         output.shares = FALSE, output.totals = FALSE, check_df = TRUE)
 {   
   
   if (check_df == TRUE)
@@ -14,18 +14,6 @@ function (huffdataset, origins, locations, attrac, dist,
     else {
       stop(paste("Dataset", as.character(substitute(huffdataset))), " not found", call. = FALSE)
     }
-
-    if (output == "total")
-    {
-      if (exists(as.character(substitute(localmarket_dataset)))) { 
-        checkdf(localmarket_dataset, origin_id, localmarket)
-      }
-      else {
-        stop(paste("Dataset", as.character(substitute(localmarket_dataset))), " not found", call. = FALSE)
-      }
-      
-    }
-   
   }
   
   sort_i_j <- order(huffdataset[[origins]], huffdataset[[locations]])   
@@ -43,16 +31,22 @@ function (huffdataset, origins, locations, attrac, dist,
 
   locations_count <- nlevels(as.factor(as.character(huffworkfile[[locations]])))
 
-  if (atype=="pow") { attrac_w <- huffworkfile[[attrac]]^gamma }
-  if (atype=="exp") { attrac_w <- exp(gamma*huffworkfile[[attrac]]) }
-  if (atype=="logistic") { attrac_w <- (1/(1+exp(gamma2+gamma*huffworkfile[[attrac]]))) }
-  
-  if (dtype=="pow") { dist_w <- huffworkfile[[dist]]^lambda } 
-  if (dtype=="exp") { dist_w <- exp(lambda*huffworkfile[[dist]]) }
-  if (dtype=="logistic") { dist_w <- (1/(1+exp(lambda2+lambda*huffworkfile[[dist]]))) }
-  
+  if (atype == "exp") { attrac_w <- exp(gamma*huffworkfile[[attrac]]) }
+  else if (atype == "logistic") { attrac_w <- (1/(1+exp(gamma2+gamma*huffworkfile[[attrac]]))) }
+  else { 
+    atype <- "pow"
+    attrac_w <- huffworkfile[[attrac]]^gamma 
+    }
+
+  if (dtype == "exp") { dist_w <- exp(lambda*huffworkfile[[dist]]) }
+  else if (dtype == "logistic") { dist_w <- (1/(1+exp(lambda2+lambda*huffworkfile[[dist]]))) }
+  else { 
+    dtype <- "pow"
+    dist_w <- huffworkfile[[dist]]^lambda 
+    }
+
   U_ij <- attrac_w * dist_w 
- 
+
   huffworkfile$U_ij <- as.numeric(U_ij)
 
   sum_U_ij <- vector()
@@ -65,7 +59,7 @@ function (huffdataset, origins, locations, attrac, dist,
     sum_U_ij_i <- sum(as.numeric(origin_i$U_ij))
 
     for (j in 1:locations_count) {   
- 
+
       sum_U_ij_all <- rbind(sum_U_ij_all, list(sum_U_ij_i)) 
     }
   }
@@ -75,28 +69,79 @@ function (huffdataset, origins, locations, attrac, dist,
   
   huffworkfile$p_ij <- as.numeric(huffworkfile$U_ij)/as.numeric(unlist(huffworkfile$sum_U_ij))
 
-  if (output == "total")
-  {
+  if (!is.null(localmarket_dataset)) {
+
+    
+    if (check_df == TRUE)
+    {
+      if (exists(as.character(substitute(localmarket_dataset)))) { 
+        checkdf(localmarket_dataset, origin_id, localmarket)
+      }
+      else {
+        stop(paste("Dataset", as.character(substitute(localmarket_dataset))), " not found", call. = FALSE)
+      }
+      
+    }
+    
     huffworkfile <- merge (huffworkfile, localmarket_dataset, by.x = colnames(huffworkfile[origins]), by.y = colnames(localmarket_dataset[origin_id]))
 
     huffworkfile$E_ij <- as.numeric(huffworkfile$p_ij) * as.numeric(huffworkfile[[localmarket]])
 
-    sum_E_j <- vector()
+    totals <- aggregate (huffworkfile$E_ij, by = list(huffworkfile[[locations]]), FUN = sum, na.rm = TRUE)
 
-    for (j in 1:locations_count) {   
-      location_j <- subset (huffworkfile, huffworkfile[[locations]] == locations_single[j])   
-      sum_E_j[j] <- sum(as.numeric(location_j$E_ij), na.rm = TRUE)   
-    }
+    colnames (totals) <- c(colnames(huffworkfile[locations]), "T_j")
     
-    E_j_output <- data.frame(locations_single, sum_E_j)   
-    E_j_output$share_j <- E_j_output$sum_E_j/sum(E_j_output$sum_E_j, na.rm = TRUE)   
+    totals$T_j_share <- totals$T_j/sum(totals$T_j, na.rm = TRUE)   
 
-    return(E_j_output)
+    results <- list (ijmatrix = huffworkfile, totals = totals)
+  }
+
+  else 
+  {
+    results <- list (ijmatrix = huffworkfile)
+  }
+ 
+
+  cat ("Huff Model", "\n")
+  cat ("\n")
+  cat ("Summary:", "\n")
+  cat (locations_count, "locations with mean attractivity =", mean(huffdataset[[attrac]]), "\n")
+  cat (origins_count, "origins with mean transport costs =", mean(huffdataset[[dist]]), "\n")
+  
+  if (atype == "logistic") {
+    cat (paste0("Attractivity weighting (", atype, ") with Gamma1 = ", gamma, " and Gamma2 = ", gamma2), "\n")  
+  }
+  else { 
+    cat (paste0("Attractivity weighting (", atype, ") with Gamma = ", gamma), "\n")
   }
   
-  else
-  {
-    return(huffworkfile)   
+  if (dtype == "logistic") {
+    cat (paste0("Distance weighting (", dtype, ") with Lambda1 = ", lambda, " and Lambda2 = ", lambda2), "\n")  
   }
+  else {
+    cat (paste0("Distance weighting (", dtype, ") with Lambda = ", lambda), "\n")  
+  }
+  
+  
+  if (!is.null(localmarket_dataset)) { 
+  cat ("Mean of total market areas =", mean(totals$T_j), "\n")  
+    
+    }
+  
+  if (output.shares == TRUE) {
+    cat ("\n")
+    cat ("Interaction matrix", "\n")
+    print (as.data.frame(huffworkfile))
+  }
+    
+  if ((!is.null(localmarket_dataset)) && output.totals == TRUE) {
+    cat ("\n")
+    cat ("Total market areas", "\n")
+    print (as.data.frame(totals))
+  } 
+  
+  
+  invisible(results)
+
   
 }
